@@ -8,6 +8,7 @@ from tqdm import tqdm
 import torch
 import torch.nn.functional as F
 from torch import nn, einsum
+from torch.cuda.amp import autocast
 import torchvision.transforms as T
 
 import kornia.augmentation as K
@@ -471,7 +472,9 @@ class ElucidatedImagen(nn.Module):
         cond_images = maybe(cast_uint8_images_to_float)(cond_images)
 
         if exists(texts) and not exists(text_embeds) and not self.unconditional:
-            text_embeds, text_masks = self.encode_text(texts, return_attn_mask = True)
+            with autocast(enabled = False):
+                text_embeds, text_masks = self.encode_text(texts, return_attn_mask = True)
+
             text_embeds, text_masks = map(lambda t: t.to(device), (text_embeds, text_masks))
 
         if not self.unconditional:
@@ -590,7 +593,9 @@ class ElucidatedImagen(nn.Module):
         if exists(texts) and not exists(text_embeds) and not self.unconditional:
             assert len(texts) == len(images), 'number of text captions does not match up with the number of images given'
 
-            text_embeds, text_masks = self.encode_text(texts, return_attn_mask = True)
+            with autocast(enabled = False):
+                text_embeds, text_masks = self.encode_text(texts, return_attn_mask = True)
+
             text_embeds, text_masks = map(lambda t: t.to(images.device), (text_embeds, text_masks))
 
         if not self.unconditional:
